@@ -2,7 +2,7 @@ package Object::HashBase;
 use strict;
 use warnings;
 
-our $VERSION = '0.006';
+our $VERSION = '0.007';
 our $HB_VERSION = $VERSION;
 # The next line is for inlining
 # <-- START -->
@@ -30,6 +30,8 @@ BEGIN {
 my %STRIP = (
     '^' => 1,
     '-' => 1,
+    '>' => 1,
+    '<' => 1,
 );
 
 sub import {
@@ -54,11 +56,30 @@ sub import {
                 substr($x, 0, 1) = '' if $STRIP{$p};
                 push @$attr_list => $x;
                 my ($sub, $attr) = (uc $x, $x);
-                $sub => ($attr_subs->{$sub} = sub() { $attr }),
-                    $attr => sub { $_[0]->{$attr} },
-                      $p eq '-' ? ("set_$attr" => sub { Carp::croak("'$attr' is read-only") })
-                    : $p eq '^' ? ("set_$attr" => sub { Carp::carp("set_$attr() is deprecated"); $_[0]->{$attr} = $_[1] })
-                    : ("set_$attr" => sub { $_[0]->{$attr} = $_[1] }),
+
+                $attr_subs->{$sub} = sub() { $attr };
+                my %out = ($sub => $attr_subs->{$sub});
+
+                if ($p eq '>') {
+                    $out{"set_$attr"} = sub { $_[0]->{$attr} = $_[1] };
+                }
+                elsif ($p eq '<') {
+                    $out{$attr} = sub { $_[0]->{$attr} };
+                }
+                else {
+                    $out{$attr} = sub { $_[0]->{$attr} };
+                    if ($p eq '-') {
+                      $out{"set_$attr"} = sub { Carp::croak("'$attr' is read-only") };
+                    }
+                    elsif ($p eq '^') {
+                        $out{"set_$attr"} = sub { Carp::carp("set_$attr() is deprecated"); $_[0]->{$attr} = $_[1] };
+                    }
+                    else {
+                        $out{"set_$attr"} = sub { $_[0]->{$attr} = $_[1] };
+                    }
+                }
+
+                %out;
             } @_
         ),
     );
